@@ -1,6 +1,7 @@
 # Copyright 2022 Rafe Kaplan
 # SPDX-License-Identifier: Apache-2.0
-
+#
+# Updated: 2022-05-30
 import dataclasses
 import datetime
 import logging
@@ -8,7 +9,6 @@ import pathlib
 from typing import Optional
 from typing import Union
 
-import conhead.template
 from conhead import config
 from conhead import template
 
@@ -59,6 +59,8 @@ def check_path(
     now: datetime.datetime,
     logger: logging.Logger,
     path: Union[pathlib.Path, str],
+    *,
+    ignore_missing_template,
 ) -> CheckResult:
     """
     Check path to see if file exists, has header and header up to date.
@@ -72,12 +74,25 @@ def check_path(
     if isinstance(path, str):
         path = pathlib.Path(path)
 
-    logger.info("process %s", path)
     up_to_date = False
     content = None
-    header_def = None
     updated_values = None
     parsed_values = None
+
+    header_def = cfg.header_for_path(path)
+    if not header_def and ignore_missing_template:
+        logger.debug("skipping: %s", path)
+        return CheckResult(
+            up_to_date, content, header_def, updated_values, parsed_values
+        )
+
+    logger.debug("checking: %s", path)
+    if not header_def:
+        logger.error("no header def: %s", path)
+        return CheckResult(
+            up_to_date, content, header_def, updated_values, parsed_values
+        )
+
     try:
         content = path.read_text()
     except FileNotFoundError:
@@ -96,13 +111,6 @@ def check_path(
             up_to_date, content, header_def, updated_values, parsed_values
         )
 
-    header_def = cfg.header_for_path(path)
-    if not header_def:
-        logger.error("no header def: %s", path)
-        return CheckResult(
-            up_to_date, content, header_def, updated_values, parsed_values
-        )
-
     parsed_values = header_def.parser.parse_fields(content)
     if parsed_values is None:
         logger.warning("missing header: %s", path)
@@ -110,9 +118,7 @@ def check_path(
             up_to_date, content, header_def, updated_values, parsed_values
         )
 
-    updated_values = tuple(
-        conhead.template.Years(d.start, now.year) for d in parsed_values.fields
-    )
+    updated_values = tuple(d.update(now) for d in parsed_values.fields)
     if updated_values != parsed_values.fields:
         logger.warning("out of date: %s", path)
         updated_values = updated_values
